package com.ruoyi.system.mapper;

import com.ruoyi.system.domain.ActHistoryRoleTypeCodeModel;
import com.ruoyi.system.domain.ActReadHistoryModel;
import com.ruoyi.system.domain.ActSuppliesImportCleaningAcc;
import org.apache.ibatis.annotations.MapKey;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;

import java.util.List;
import java.util.Map;

/**
 * 2024/3/21
 */
@Repository
public interface ActReadDataMapper {
    List<ActReadHistoryModel> readDateToHistory(@Param("id") String mineId, @Param("c") int c);

    void insertDateToAnalysisAfter(@Param("accList") List<ActSuppliesImportCleaningAcc> accList);

    List<ActHistoryRoleTypeCodeModel> selectMaterialCode();

    void updateState(@Param("id") String yyUuid);

    int selectCleanToOne(@Param("id") String mineId);

    int readOfMId(@Param("id") String mineId, @Param("fDate") String format);

    String selectOfMIdToHis(@Param("id") String mineId, @Param("fDate") String format);

    void deleteOfMIdToHis(@Param("id")String mineId, @Param("ny") String dateNY);

    void deleteOfMIdToClear(@Param("id")String mineId, @Param("ny") String dateNY);

    void deleteToContent(@Param("uuid")String s);
}
